@@ -238,278 +238,293 @@ _PROPERTIES = """\
 70 InThaana Thaana
 71 InNKo NKo
 72 InSamaritan Samaritan
-73 Devanagari InDevanagari
-74 Bengali InBengali
-75 Gurmukhi InGurmukhi
-76 Gujarati InGujarati
-77 InOriya Oriya
-78 InTamil Tamil
-79 InTelugu Telugu
-80 InKannada Kannada
-81 InMalayalam Malayalam
-82 InSinhala Sinhala
-83 InThai Thai
-84 InLao Lao
-85 InTibetan Tibetan
-86 InMyanmar Myanmar
-87 Georgian InGeorgian
-88 HangulJamo InHangulJamo
-89 Ethiopic InEthiopic
-90 EthiopicSupplement InEthiopicSupplement
-91 Cherokee InCherokee
-92 InUnifiedCanadianAboriginalSyllabics UnifiedCanadianAboriginalSyllabics
-93 InOgham Ogham
-94 InRunic Runic
-95 InTagalog Tagalog
-96 Hanunoo InHanunoo
-97 Buhid InBuhid
-98 InTagbanwa Tagbanwa
-99 InKhmer Khmer
-100 InMongolian Mongolian
-101 InUnifiedCanadianAboriginalSyllabicsExtended UnifiedCanadianAboriginalSyllabicsExtended
-102 InLimbu Limbu
-103 InTaiLe TaiLe
-104 InNewTaiLue NewTaiLue
-105 InKhmerSymbols KhmerSymbols
-106 Buginese InBuginese
-107 InTaiTham TaiTham
-108 Balinese InBalinese
-109 InSundanese Sundanese
-110 InLepcha Lepcha
-111 InOlChiki OlChiki
-112 InVedicExtensions VedicExtensions
-113 InPhoneticExtensions PhoneticExtensions
-114 InPhoneticExtensionsSupplement PhoneticExtensionsSupplement
-115 CombiningDiacriticalMarksSupplement InCombiningDiacriticalMarksSupplement
-116 InLatinExtendedAdditional LatinExtendedAdditional
-117 GreekExtended InGreekExtended
-118 GeneralPunctuation InGeneralPunctuation
-119 InSuperscriptsandSubscripts SuperscriptsandSubscripts
-120 CurrencySymbols InCurrencySymbols
-121 CombiningDiacriticalMarksforSymbols InCombiningDiacriticalMarksforSymbols
-122 InLetterlikeSymbols LetterlikeSymbols
-123 InNumberForms NumberForms
-124 Arrows InArrows
-125 InMathematicalOperators MathematicalOperators
-126 InMiscellaneousTechnical MiscellaneousTechnical
-127 ControlPictures InControlPictures
-128 InOpticalCharacterRecognition OpticalCharacterRecognition
-129 EnclosedAlphanumerics InEnclosedAlphanumerics
-130 BoxDrawing InBoxDrawing
-131 BlockElements InBlockElements
-132 GeometricShapes InGeometricShapes
-133 InMiscellaneousSymbols MiscellaneousSymbols
-134 Dingbats InDingbats
-135 InMiscellaneousMathematicalSymbolsA MiscellaneousMathematicalSymbolsA
-136 InSupplementalArrowsA SupplementalArrowsA
-137 BraillePatterns InBraillePatterns
-138 InSupplementalArrowsB SupplementalArrowsB
-139 InMiscellaneousMathematicalSymbolsB MiscellaneousMathematicalSymbolsB
-140 InSupplementalMathematicalOperators SupplementalMathematicalOperators
-141 InMiscellaneousSymbolsandArrows MiscellaneousSymbolsandArrows
-142 Glagolitic InGlagolitic
-143 InLatinExtendedC LatinExtendedC
-144 Coptic InCoptic
-145 GeorgianSupplement InGeorgianSupplement
-146 InTifinagh Tifinagh
-147 EthiopicExtended InEthiopicExtended
-148 CyrillicExtendedA InCyrillicExtendedA
-149 InSupplementalPunctuation SupplementalPunctuation
-150 CJKRadicalsSupplement InCJKRadicalsSupplement
-151 InKangxiRadicals KangxiRadicals
-152 IdeographicDescriptionCharacters InIdeographicDescriptionCharacters
-153 CJKSymbolsandPunctuation InCJKSymbolsandPunctuation
-154 Hiragana InHiragana
-155 InKatakana Katakana
-156 Bopomofo InBopomofo
-157 HangulCompatibilityJamo InHangulCompatibilityJamo
-158 InKanbun Kanbun
-159 BopomofoExtended InBopomofoExtended
-160 CJKStrokes InCJKStrokes
-161 InKatakanaPhoneticExtensions KatakanaPhoneticExtensions
-162 EnclosedCJKLettersandMonths InEnclosedCJKLettersandMonths
-163 CJKCompatibility InCJKCompatibility
-164 CJKUnifiedIdeographsExtensionA InCJKUnifiedIdeographsExtensionA
-165 InYijingHexagramSymbols YijingHexagramSymbols
-166 CJKUnifiedIdeographs InCJKUnifiedIdeographs
-167 InYiSyllables YiSyllables
-168 InYiRadicals YiRadicals
-169 InLisu Lisu
-170 InVai Vai
-171 CyrillicExtendedB InCyrillicExtendedB
-172 Bamum InBamum
-173 InModifierToneLetters ModifierToneLetters
-174 InLatinExtendedD LatinExtendedD
-175 InSylotiNagri SylotiNagri
-176 CommonIndicNumberForms InCommonIndicNumberForms
-177 InPhagspa Phagspa
-178 InSaurashtra Saurashtra
-179 DevanagariExtended InDevanagariExtended
-180 InKayahLi KayahLi
-181 InRejang Rejang
-182 HangulJamoExtendedA InHangulJamoExtendedA
-183 InJavanese Javanese
-184 Cham InCham
-185 InMyanmarExtendedA MyanmarExtendedA
-186 InTaiViet TaiViet
-187 InMeeteiMayek MeeteiMayek
-188 HangulSyllables InHangulSyllables
-189 HangulJamoExtendedB InHangulJamoExtendedB
-190 HighSurrogates InHighSurrogates
-191 HighPrivateUseSurrogates InHighPrivateUseSurrogates
-192 InLowSurrogates LowSurrogates
-193 InPrivateUseArea PrivateUseArea
-194 CJKCompatibilityIdeographs InCJKCompatibilityIdeographs
-195 AlphabeticPresentationForms InAlphabeticPresentationForms
-196 ArabicPresentationFormsA InArabicPresentationFormsA
-197 InVariationSelectors VariationSelectors
-198 InVerticalForms VerticalForms
-199 CombiningHalfMarks InCombiningHalfMarks
-200 CJKCompatibilityForms InCJKCompatibilityForms
-201 InSmallFormVariants SmallFormVariants
-202 ArabicPresentationFormsB InArabicPresentationFormsB
-203 HalfwidthandFullwidthForms InHalfwidthandFullwidthForms
-204 InSpecials Specials
-205 InLinearBSyllabary LinearBSyllabary
-206 InLinearBIdeograms LinearBIdeograms
-207 AegeanNumbers InAegeanNumbers
-208 AncientGreekNumbers InAncientGreekNumbers
-209 AncientSymbols InAncientSymbols
-210 InPhaistosDisc PhaistosDisc
-211 InLycian Lycian
-212 Carian InCarian
-213 InOldItalic OldItalic
-214 Gothic InGothic
-215 InUgaritic Ugaritic
-216 InOldPersian OldPersian
-217 Deseret InDeseret
-218 InShavian Shavian
-219 InOsmanya Osmanya
-220 CypriotSyllabary InCypriotSyllabary
-221 ImperialAramaic InImperialAramaic
-222 InPhoenician Phoenician
-223 InLydian Lydian
-224 InKharoshthi Kharoshthi
-225 InOldSouthArabian OldSouthArabian
-226 Avestan InAvestan
-227 InInscriptionalParthian InscriptionalParthian
-228 InInscriptionalPahlavi InscriptionalPahlavi
-229 InOldTurkic OldTurkic
-230 InRumiNumeralSymbols RumiNumeralSymbols
-231 InKaithi Kaithi
-232 Cuneiform InCuneiform
-233 CuneiformNumbersandPunctuation InCuneiformNumbersandPunctuation
-234 EgyptianHieroglyphs InEgyptianHieroglyphs
-235 ByzantineMusicalSymbols InByzantineMusicalSymbols
-236 InMusicalSymbols MusicalSymbols
-237 AncientGreekMusicalNotation InAncientGreekMusicalNotation
-238 InTaiXuanJingSymbols TaiXuanJingSymbols
-239 CountingRodNumerals InCountingRodNumerals
-240 InMathematicalAlphanumericSymbols MathematicalAlphanumericSymbols
-241 InMahjongTiles MahjongTiles
-242 DominoTiles InDominoTiles
-243 EnclosedAlphanumericSupplement InEnclosedAlphanumericSupplement
-244 EnclosedIdeographicSupplement InEnclosedIdeographicSupplement
-245 CJKUnifiedIdeographsExtensionB InCJKUnifiedIdeographsExtensionB
-246 CJKUnifiedIdeographsExtensionC InCJKUnifiedIdeographsExtensionC
-247 CJKCompatibilityIdeographsSupplement InCJKCompatibilityIdeographsSupplement
-248 InTags Tags
-249 InVariationSelectorsSupplement VariationSelectorsSupplement
-250 InSupplementaryPrivateUseAreaA SupplementaryPrivateUseAreaA
-251 InSupplementaryPrivateUseAreaB SupplementaryPrivateUseAreaB
-252 IsUnknown Unknown
-253 Common IsCommon
-254 IsLatin Latin
-255 Greek IsGreek
-256 Cyrillic IsCyrillic
-257 Armenian IsArmenian
-258 Hebrew IsHebrew
-259 Arabic IsArabic
-260 IsSyriac Syriac
-261 IsThaana Thaana
-262 Devanagari IsDevanagari
-263 Bengali IsBengali
-264 Gurmukhi IsGurmukhi
-265 Gujarati IsGujarati
-266 IsOriya Oriya
-267 IsTamil Tamil
-268 IsTelugu Telugu
-269 IsKannada Kannada
-270 IsMalayalam Malayalam
-271 IsSinhala Sinhala
-272 IsThai Thai
-273 IsLao Lao
-274 IsTibetan Tibetan
-275 IsMyanmar Myanmar
-276 Georgian IsGeorgian
-277 Hangul IsHangul
-278 Ethiopic IsEthiopic
-279 Cherokee IsCherokee
-280 CanadianAboriginal IsCanadianAboriginal
-281 IsOgham Ogham
-282 IsRunic Runic
-283 IsKhmer Khmer
-284 IsMongolian Mongolian
-285 Hiragana IsHiragana
-286 IsKatakana Katakana
-287 Bopomofo IsBopomofo
-288 Han IsHan
-289 IsYi Yi
-290 IsOldItalic OldItalic
-291 Gothic IsGothic
-292 Deseret IsDeseret
-293 Inherited IsInherited
-294 IsTagalog Tagalog
-295 Hanunoo IsHanunoo
-296 Buhid IsBuhid
-297 IsTagbanwa Tagbanwa
-298 IsLimbu Limbu
-299 IsTaiLe TaiLe
-300 IsLinearB LinearB
-301 IsUgaritic Ugaritic
-302 IsShavian Shavian
-303 IsOsmanya Osmanya
-304 Cypriot IsCypriot
-305 Braille IsBraille
-306 Buginese IsBuginese
-307 Coptic IsCoptic
-308 IsNewTaiLue NewTaiLue
-309 Glagolitic IsGlagolitic
-310 IsTifinagh Tifinagh
-311 IsSylotiNagri SylotiNagri
-312 IsOldPersian OldPersian
-313 IsKharoshthi Kharoshthi
-314 Balinese IsBalinese
-315 Cuneiform IsCuneiform
-316 IsPhoenician Phoenician
-317 IsPhagsPa PhagsPa
-318 IsNko Nko
-319 IsSundanese Sundanese
-320 IsLepcha Lepcha
-321 IsOlChiki OlChiki
-322 IsVai Vai
-323 IsSaurashtra Saurashtra
-324 IsKayahLi KayahLi
-325 IsRejang Rejang
-326 IsLycian Lycian
-327 Carian IsCarian
-328 IsLydian Lydian
-329 Cham IsCham
-330 IsTaiTham TaiTham
-331 IsTaiViet TaiViet
-332 Avestan IsAvestan
-333 EgyptianHieroglyphs IsEgyptianHieroglyphs
-334 IsSamaritan Samaritan
-335 IsLisu Lisu
-336 Bamum IsBamum
-337 IsJavanese Javanese
-338 IsMeeteiMayek MeeteiMayek
-339 ImperialAramaic IsImperialAramaic
-340 IsOldSouthArabian OldSouthArabian
-341 InscriptionalParthian IsInscriptionalParthian
-342 InscriptionalPahlavi IsInscriptionalPahlavi
-343 IsOldTurkic OldTurkic
-344 IsKaithi Kaithi
+73 InMandaic Mandaic
+74 Devanagari InDevanagari
+75 Bengali InBengali
+76 Gurmukhi InGurmukhi
+77 Gujarati InGujarati
+78 InOriya Oriya
+79 InTamil Tamil
+80 InTelugu Telugu
+81 InKannada Kannada
+82 InMalayalam Malayalam
+83 InSinhala Sinhala
+84 InThai Thai
+85 InLao Lao
+86 InTibetan Tibetan
+87 InMyanmar Myanmar
+88 Georgian InGeorgian
+89 HangulJamo InHangulJamo
+90 Ethiopic InEthiopic
+91 EthiopicSupplement InEthiopicSupplement
+92 Cherokee InCherokee
+93 InUnifiedCanadianAboriginalSyllabics UnifiedCanadianAboriginalSyllabics
+94 InOgham Ogham
+95 InRunic Runic
+96 InTagalog Tagalog
+97 Hanunoo InHanunoo
+98 Buhid InBuhid
+99 InTagbanwa Tagbanwa
+100 InKhmer Khmer
+101 InMongolian Mongolian
+102 InUnifiedCanadianAboriginalSyllabicsExtended UnifiedCanadianAboriginalSyllabicsExtended
+103 InLimbu Limbu
+104 InTaiLe TaiLe
+105 InNewTaiLue NewTaiLue
+106 InKhmerSymbols KhmerSymbols
+107 Buginese InBuginese
+108 InTaiTham TaiTham
+109 Balinese InBalinese
+110 InSundanese Sundanese
+111 Batak InBatak
+112 InLepcha Lepcha
+113 InOlChiki OlChiki
+114 InVedicExtensions VedicExtensions
+115 InPhoneticExtensions PhoneticExtensions
+116 InPhoneticExtensionsSupplement PhoneticExtensionsSupplement
+117 CombiningDiacriticalMarksSupplement InCombiningDiacriticalMarksSupplement
+118 InLatinExtendedAdditional LatinExtendedAdditional
+119 GreekExtended InGreekExtended
+120 GeneralPunctuation InGeneralPunctuation
+121 InSuperscriptsandSubscripts SuperscriptsandSubscripts
+122 CurrencySymbols InCurrencySymbols
+123 CombiningDiacriticalMarksforSymbols InCombiningDiacriticalMarksforSymbols
+124 InLetterlikeSymbols LetterlikeSymbols
+125 InNumberForms NumberForms
+126 Arrows InArrows
+127 InMathematicalOperators MathematicalOperators
+128 InMiscellaneousTechnical MiscellaneousTechnical
+129 ControlPictures InControlPictures
+130 InOpticalCharacterRecognition OpticalCharacterRecognition
+131 EnclosedAlphanumerics InEnclosedAlphanumerics
+132 BoxDrawing InBoxDrawing
+133 BlockElements InBlockElements
+134 GeometricShapes InGeometricShapes
+135 InMiscellaneousSymbols MiscellaneousSymbols
+136 Dingbats InDingbats
+137 InMiscellaneousMathematicalSymbolsA MiscellaneousMathematicalSymbolsA
+138 InSupplementalArrowsA SupplementalArrowsA
+139 BraillePatterns InBraillePatterns
+140 InSupplementalArrowsB SupplementalArrowsB
+141 InMiscellaneousMathematicalSymbolsB MiscellaneousMathematicalSymbolsB
+142 InSupplementalMathematicalOperators SupplementalMathematicalOperators
+143 InMiscellaneousSymbolsandArrows MiscellaneousSymbolsandArrows
+144 Glagolitic InGlagolitic
+145 InLatinExtendedC LatinExtendedC
+146 Coptic InCoptic
+147 GeorgianSupplement InGeorgianSupplement
+148 InTifinagh Tifinagh
+149 EthiopicExtended InEthiopicExtended
+150 CyrillicExtendedA InCyrillicExtendedA
+151 InSupplementalPunctuation SupplementalPunctuation
+152 CJKRadicalsSupplement InCJKRadicalsSupplement
+153 InKangxiRadicals KangxiRadicals
+154 IdeographicDescriptionCharacters InIdeographicDescriptionCharacters
+155 CJKSymbolsandPunctuation InCJKSymbolsandPunctuation
+156 Hiragana InHiragana
+157 InKatakana Katakana
+158 Bopomofo InBopomofo
+159 HangulCompatibilityJamo InHangulCompatibilityJamo
+160 InKanbun Kanbun
+161 BopomofoExtended InBopomofoExtended
+162 CJKStrokes InCJKStrokes
+163 InKatakanaPhoneticExtensions KatakanaPhoneticExtensions
+164 EnclosedCJKLettersandMonths InEnclosedCJKLettersandMonths
+165 CJKCompatibility InCJKCompatibility
+166 CJKUnifiedIdeographsExtensionA InCJKUnifiedIdeographsExtensionA
+167 InYijingHexagramSymbols YijingHexagramSymbols
+168 CJKUnifiedIdeographs InCJKUnifiedIdeographs
+169 InYiSyllables YiSyllables
+170 InYiRadicals YiRadicals
+171 InLisu Lisu
+172 InVai Vai
+173 CyrillicExtendedB InCyrillicExtendedB
+174 Bamum InBamum
+175 InModifierToneLetters ModifierToneLetters
+176 InLatinExtendedD LatinExtendedD
+177 InSylotiNagri SylotiNagri
+178 CommonIndicNumberForms InCommonIndicNumberForms
+179 InPhagspa Phagspa
+180 InSaurashtra Saurashtra
+181 DevanagariExtended InDevanagariExtended
+182 InKayahLi KayahLi
+183 InRejang Rejang
+184 HangulJamoExtendedA InHangulJamoExtendedA
+185 InJavanese Javanese
+186 Cham InCham
+187 InMyanmarExtendedA MyanmarExtendedA
+188 InTaiViet TaiViet
+189 EthiopicExtendedA InEthiopicExtendedA
+190 InMeeteiMayek MeeteiMayek
+191 HangulSyllables InHangulSyllables
+192 HangulJamoExtendedB InHangulJamoExtendedB
+193 HighSurrogates InHighSurrogates
+194 HighPrivateUseSurrogates InHighPrivateUseSurrogates
+195 InLowSurrogates LowSurrogates
+196 InPrivateUseArea PrivateUseArea
+197 CJKCompatibilityIdeographs InCJKCompatibilityIdeographs
+198 AlphabeticPresentationForms InAlphabeticPresentationForms
+199 ArabicPresentationFormsA InArabicPresentationFormsA
+200 InVariationSelectors VariationSelectors
+201 InVerticalForms VerticalForms
+202 CombiningHalfMarks InCombiningHalfMarks
+203 CJKCompatibilityForms InCJKCompatibilityForms
+204 InSmallFormVariants SmallFormVariants
+205 ArabicPresentationFormsB InArabicPresentationFormsB
+206 HalfwidthandFullwidthForms InHalfwidthandFullwidthForms
+207 InSpecials Specials
+208 InLinearBSyllabary LinearBSyllabary
+209 InLinearBIdeograms LinearBIdeograms
+210 AegeanNumbers InAegeanNumbers
+211 AncientGreekNumbers InAncientGreekNumbers
+212 AncientSymbols InAncientSymbols
+213 InPhaistosDisc PhaistosDisc
+214 InLycian Lycian
+215 Carian InCarian
+216 InOldItalic OldItalic
+217 Gothic InGothic
+218 InUgaritic Ugaritic
+219 InOldPersian OldPersian
+220 Deseret InDeseret
+221 InShavian Shavian
+222 InOsmanya Osmanya
+223 CypriotSyllabary InCypriotSyllabary
+224 ImperialAramaic InImperialAramaic
+225 InPhoenician Phoenician
+226 InLydian Lydian
+227 InKharoshthi Kharoshthi
+228 InOldSouthArabian OldSouthArabian
+229 Avestan InAvestan
+230 InInscriptionalParthian InscriptionalParthian
+231 InInscriptionalPahlavi InscriptionalPahlavi
+232 InOldTurkic OldTurkic
+233 InRumiNumeralSymbols RumiNumeralSymbols
+234 Brahmi InBrahmi
+235 InKaithi Kaithi
+236 Cuneiform InCuneiform
+237 CuneiformNumbersandPunctuation InCuneiformNumbersandPunctuation
+238 EgyptianHieroglyphs InEgyptianHieroglyphs
+239 BamumSupplement InBamumSupplement
+240 InKanaSupplement KanaSupplement
+241 ByzantineMusicalSymbols InByzantineMusicalSymbols
+242 InMusicalSymbols MusicalSymbols
+243 AncientGreekMusicalNotation InAncientGreekMusicalNotation
+244 InTaiXuanJingSymbols TaiXuanJingSymbols
+245 CountingRodNumerals InCountingRodNumerals
+246 InMathematicalAlphanumericSymbols MathematicalAlphanumericSymbols
+247 InMahjongTiles MahjongTiles
+248 DominoTiles InDominoTiles
+249 InPlayingCards PlayingCards
+250 EnclosedAlphanumericSupplement InEnclosedAlphanumericSupplement
+251 EnclosedIdeographicSupplement InEnclosedIdeographicSupplement
+252 InMiscellaneousSymbolsAndPictographs MiscellaneousSymbolsAndPictographs
+253 Emoticons InEmoticons
+254 InTransportAndMapSymbols TransportAndMapSymbols
+255 AlchemicalSymbols InAlchemicalSymbols
+256 CJKUnifiedIdeographsExtensionB InCJKUnifiedIdeographsExtensionB
+257 CJKUnifiedIdeographsExtensionC InCJKUnifiedIdeographsExtensionC
+258 CJKUnifiedIdeographsExtensionD InCJKUnifiedIdeographsExtensionD
+259 CJKCompatibilityIdeographsSupplement InCJKCompatibilityIdeographsSupplement
+260 InTags Tags
+261 InVariationSelectorsSupplement VariationSelectorsSupplement
+262 InSupplementaryPrivateUseAreaA SupplementaryPrivateUseAreaA
+263 InSupplementaryPrivateUseAreaB SupplementaryPrivateUseAreaB
+264 IsUnknown Unknown
+265 Common IsCommon
+266 IsLatin Latin
+267 Greek IsGreek
+268 Cyrillic IsCyrillic
+269 Armenian IsArmenian
+270 Hebrew IsHebrew
+271 Arabic IsArabic
+272 IsSyriac Syriac
+273 IsThaana Thaana
+274 Devanagari IsDevanagari
+275 Bengali IsBengali
+276 Gurmukhi IsGurmukhi
+277 Gujarati IsGujarati
+278 IsOriya Oriya
+279 IsTamil Tamil
+280 IsTelugu Telugu
+281 IsKannada Kannada
+282 IsMalayalam Malayalam
+283 IsSinhala Sinhala
+284 IsThai Thai
+285 IsLao Lao
+286 IsTibetan Tibetan
+287 IsMyanmar Myanmar
+288 Georgian IsGeorgian
+289 Hangul IsHangul
+290 Ethiopic IsEthiopic
+291 Cherokee IsCherokee
+292 CanadianAboriginal IsCanadianAboriginal
+293 IsOgham Ogham
+294 IsRunic Runic
+295 IsKhmer Khmer
+296 IsMongolian Mongolian
+297 Hiragana IsHiragana
+298 IsKatakana Katakana
+299 Bopomofo IsBopomofo
+300 Han IsHan
+301 IsYi Yi
+302 IsOldItalic OldItalic
+303 Gothic IsGothic
+304 Deseret IsDeseret
+305 Inherited IsInherited
+306 IsTagalog Tagalog
+307 Hanunoo IsHanunoo
+308 Buhid IsBuhid
+309 IsTagbanwa Tagbanwa
+310 IsLimbu Limbu
+311 IsTaiLe TaiLe
+312 IsLinearB LinearB
+313 IsUgaritic Ugaritic
+314 IsShavian Shavian
+315 IsOsmanya Osmanya
+316 Cypriot IsCypriot
+317 Braille IsBraille
+318 Buginese IsBuginese
+319 Coptic IsCoptic
+320 IsNewTaiLue NewTaiLue
+321 Glagolitic IsGlagolitic
+322 IsTifinagh Tifinagh
+323 IsSylotiNagri SylotiNagri
+324 IsOldPersian OldPersian
+325 IsKharoshthi Kharoshthi
+326 Balinese IsBalinese
+327 Cuneiform IsCuneiform
+328 IsPhoenician Phoenician
+329 IsPhagsPa PhagsPa
+330 IsNko Nko
+331 IsSundanese Sundanese
+332 IsLepcha Lepcha
+333 IsOlChiki OlChiki
+334 IsVai Vai
+335 IsSaurashtra Saurashtra
+336 IsKayahLi KayahLi
+337 IsRejang Rejang
+338 IsLycian Lycian
+339 Carian IsCarian
+340 IsLydian Lydian
+341 Cham IsCham
+342 IsTaiTham TaiTham
+343 IsTaiViet TaiViet
+344 Avestan IsAvestan
+345 EgyptianHieroglyphs IsEgyptianHieroglyphs
+346 IsSamaritan Samaritan
+347 IsLisu Lisu
+348 Bamum IsBamum
+349 IsJavanese Javanese
+350 IsMeeteiMayek MeeteiMayek
+351 ImperialAramaic IsImperialAramaic
+352 IsOldSouthArabian OldSouthArabian
+353 InscriptionalParthian IsInscriptionalParthian
+354 InscriptionalPahlavi IsInscriptionalPahlavi
+355 IsOldTurkic OldTurkic
+356 IsKaithi Kaithi
+357 Batak IsBatak
+358 Brahmi IsBrahmi
+359 IsMandaic Mandaic
 """
 
 def _create_properties(definitions):
